use serde::{Deserialize, Serialize};

#[cfg(feature = "server")]
use crate::util::surrealdb::{thing_to_string, DB};
#[cfg(feature = "server")]
use surrealdb::sql::{
    statements::{BeginStatement, CommitStatement},
    Thing,
};

#[derive(PartialEq, Clone, Copy, Debug, Deserialize, Serialize, Eq)]
pub enum TargetKind {
    None,
    All,
    Group,
    Hourgroup,
    Hour,
    Member,
    Account,
    Day,
}

impl TargetKind {
    pub fn from_string(input: &str) -> Self {
        match input {
            "all" => Self::All,
            "group" => Self::Group,
            "hourgroup" => Self::Hourgroup,
            "hour" => Self::Hour,
            "member" => Self::Member,
            "account" => Self::Account,
            "day" => Self::Day,
            _ => Self::None,
        }
    }
}

#[derive(PartialEq, Debug, Deserialize, Serialize, Clone, Eq)]
pub struct Target {
    pub kind: TargetKind,
    pub value: String,
}

#[derive(Debug, Deserialize, Serialize, PartialEq, Eq, Clone)]
pub struct News {
    #[cfg_attr(feature = "server", serde(deserialize_with = "thing_to_string"))]
    pub id: String,
    pub title: String,
    pub body: String,
    pub tagets: Vec<Target>,
}

#[cfg(feature = "server")]
impl News {
    // pub async fn new(
    //     title: String,
    //     body: String,
    //     targets: Vec<Target>,
    // ) -> Result<Self, crate::Error> {
    // }
}

#[cfg(feature = "server")]
fn fetch_targets(targets: Vec<Target>) {
    let mut transaction = DB.query(BeginStatement::default());

    for target in targets {}
}
